Personalized Zipper Padfolio , Add Your Message
Description: They'll command attention when they enter a room with this business must-have. A gift worthy of the corner office, this padfolio is sure to make a statement while keeping their notes and work secure and in order everywhere they go. With plenty of places to store essentials, they'll stay organized and prepared while looking great doing it. From our Pebble Grain Collection, it stands head and shoulders above the rest with its chic black pebble grain texture set off by a silver engraving area so you can send your personal message into every meeting with them. <br><br>- Includes multiple pockets and penholders and a 60-page lined 8.5" x 11" notepad <br>- Perfect for new jobs, promotions (gotta look the new part!), or recognition for winning that new account <br>- Pair it with our other Pebble Grain pieces, like the matching Desk Organizer, for an extra-special gift
Keywords: Personalized Zipper Padfolio Business Gifts Graduate Graduation Gift Grad Notebook Portfolio Folder Leather New Job Promotion Recognition Award Employee

Personalized Gifts That Inspire
FREE STANDARD SHIPPING ON ORDERS $100 OR MORE
MOST ORDERS SHIP IN 1-2 DAYS
Sign Up Now

- Personalization
- Look Books
- Blog
- Rewards Club
- Special Offers

{"dragByHandle":true,"dragByBody":false,"cssSelector":"ql-thumbnail","widgetClass":"OverlayWidget","bindings":{"bind0":{"element":".ql-thumbnail .Quicklook .trigger","type":"quicklookselected","fn":"function(){$.fnProxy(arguments,\'#headerOverlay\',OverlayWidget.show,\'OverlayWidget.show\');}"}},"effectOnHide":"slide","effectOnShowOptions":"{}","effectOnHideOptions":"{}","closeOnBackgroundClick":true,"effectOnShowSpeed":"1200","onScreenPadding":10,"allowOffScreenOverlay":false,"captureClicks":true,"effectOnShow":"slide","effectOnHideSpeed":"1200"}

Print This Page

# Zipper Padfolio

Item No. 704665
|
Share:

{ width: 312, height: 312, defaultImage: '000704665', layers: '000704665_10109' }

{"widgetClass":"BackgroundZoomWidget","bubbles":{"bubble6":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"scene7panned"},"bubble5":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"scene7imagechanged"},"bubble4":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"scene7reset"},"bubble3":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"scene7zoomout"},"bubble2":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"scene7zoomin"},"bubble1":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"ensembleproductselected"},"bubble0":{"trigger":"#ZoomPanel_trigger","element":"#ZoomPanel_EntityZoom_trigger","data":null,"type":"ensembleproducthover"}}}

{"boundSelector":"#ZoomPanel_EntityZoom_Zoom","widgetClass":"EntityZoomWidget","bubbles":{"bubble4":{"trigger":"#ZoomPanel_EntityZoom_trigger","element":"#ZoomPanel_EntityZoom_Zoom_trigger","data":null,"type":"scene7panned"},"bubble3":{"trigger":"#ZoomPanel_EntityZoom_trigger","element":"#ZoomPanel_EntityZoom_Zoom_trigger","data":null,"type":"scene7imagechanged"},"bubble2":{"trigger":"#ZoomPanel_EntityZoom_trigger","element":"#ZoomPanel_EntityZoom_Zoom_trigger","data":null,"type":"scene7reset"},"bubble1":{"trigger":"#ZoomPanel_EntityZoom_trigger","element":"#ZoomPanel_EntityZoom_Zoom_trigger","data":null,"type":"scene7zoomout"},"bubble0":{"trigger":"#ZoomPanel_EntityZoom_trigger","element":"#ZoomPanel_EntityZoom_Zoom_trigger","data":null,"type":"scene7zoomin"}}}

{"showZoomControls":true,"waitIcon":"/assets/motif/ocpsdk/generic/scene7/wait.gif","showControls":false,"widgetClass":"BaseZoomWidget","imageName":"000704665_10109","showPanControls":false,"navigatorBorderWidth":2,"baseURL":"https://thingsremembered.scene7.com/is/image/ThingsRemembered/","imageOnError":"000704665","navigatorBorderColor":"ff0000","smallerZoom":false}

Zipper Padfolio

{"widgetClass":"EntityAltImagesWidget","entityType":"product","entityName":"Zipper Padfolio"}

{ altImage: '000704665_10109' } { width: 48, height: 48, defaultImage: '000704665', layers: '000704665_10109' } { altImage: '000704665_1_lg' } { width: 48, height: 48, defaultImage: '', layers: '000704665_1_lg' }

## This personalized notebook features a popular padfolio style

They'll command attention when they enter a room with this business must-have. A gift worthy of the corner office, this padfolio is sure to make a statement while keeping their notes and work secure and in order everywhere they go. With plenty of places to store essentials, they'll stay organized and prepared while looking great doing it. From our Pebble Grain Collection, it stands head and shoulders above the rest with its chic black pebble grain texture set off by a silver engraving area so...
More
They'll command attention when they enter a room with this business must-have. A gift worthy of the corner office, this padfolio is sure to make a statement while keeping their notes and work secure and in order everywhere they go. With plenty of places to store essentials, they'll stay organized and prepared while looking great doing it. From our Pebble Grain Collection, it stands head and shoulders above the rest with its chic black pebble grain texture set off by a silver engraving area so you can send your personal message into every meeting with them.
- Includes multiple pockets and penholders and a 60-page lined 8.5" x 11" notepad
- Perfect for new jobs, promotions (gotta look the new part!), or recognition for winning that new account
- Pair it with our other Pebble Grain pieces, like the matching Desk Organizer, for an extra-special gift
Less

$70.00 $59.99 In Stock
Inventory Level: Not Available
Order Quantity
Available for store pickup

## Home Delivery Dates

Standard Delivery

Express Delivery

Express Plus Delivery

Next Business Day

Must place your order by 04:00PM

About Shipping Options

Please enter a valid ZIP code.

- Ship to Home
- Pick Up in Store Today

Details
Pick up estimate as of now: Change Pick Up Time
- Padfolio-Size: 13" x 10.5" x 1.5"
- Padfolio-Features: Padfolio with multiple pockets and pen holders and includes a 60-page lined 8.5" x 11" notepad
- Padfolio-Material: Faux leather
- Padfolio-Color: Black
Items You May Also Like

{"widgetClass":"ButtonWidget","clickFunction":"function() {$(\'#_widget944148701005\').widgetClass().scrollPrevious(\'#_widget944148701005\');}"}

{ entityId: 163105, entityType: 'product' } { width: 100, height: 100, defaultImage: '000704678', layers: '000704678' } Personalized Black Padfolio Pick Up in Store Today $60.00 $49.99 | { entityId: 158039, entityType: 'product' } { width: 100, height: 100, defaultImage: '000641883', layers: '000641883' } Cross® Avitar Satin Chrome Set Pick Up in Store Today $60.00 $48.00

{"widgetClass":"ButtonWidget","clickFunction":"function() {$(\'#_widget944148701005\').widgetClass().scrollNext(\'#_widget944148701005\');}"}

{"afterScroll":"","unitSize":177,"scrollSpeed":500,"widgetClass":"SnapToScrollerWidget","snapClosest":true,"direction":"horizontal","bindings":{"bind0":{"element":"#_widget944148701005_trigger","type":"scrollend","fn":"function(event, pageNum) {\t\t\t\t\tPagedDataSetFilmstripLoaderWidget.loadPage(\'#relatedItems\', Math.floor(pageNum));\t\t\t\t}"}},"beforeScroll":"","animateScroll":"true","scrollAmount":889}

{ entityCount: 2 }

{"imageThreshold":5,"dataModel":{"cacheEntitiesInRequest":false,"imageHeight":100,"dataProviderWidget":"com.fry.tr.widget.catalog.dataproviders.RelatedItemsDataProviderWidget","direction":"horizontal","entityTypeId":"4","entityId":"163104","itemViewerWidget":"com.fry.starter.widget.viewers.ItemViewerWidget","imageWidth":100},"widgetClass":"PagedDataSetFilmstripLoaderWidget","emptyItemViewer":"<div class=\"image\"><!-- --></div><div class=\"info\"><div class=\"name\"><!-- --></div><div class=\"price\"><!-- --></div></div>","direction":"horizontal","loadThreshold":1,"pages":2,"pageSize":5}